@@ -20,9 +20,9 @@
 #include "mcsurfaceobjectdata.hh"
 
 MCSurfaceObjectData::MCSurfaceObjectData(const std::string & typeId)
-: MCObjectData(typeId)
-, m_surfaceId(typeId)
-, m_defaultCircleShape(false)
+  : MCObjectData(typeId)
+  , m_surfaceId(typeId)
+  , m_defaultCircleShape(false)
 {
 }
 
@@ -41,7 +41,9 @@ void MCSurfaceObjectData::setDefaultCircleShape(bool state)
     m_defaultCircleShape = state;
 }
 
-bool MCSurfaceObjectData::defaultCirleShape() const
+bool MCSurfaceObjectData::defaultCircleShape() const
 {
     return m_defaultCircleShape;
 }
+
+MCSurfaceObjectData::~MCSurfaceObjectData() = default;
