@@ -14,8 +14,8 @@
 // along with Dust Racing 2D. If not, see <http://www.gnu.org/licenses/>.
 
 #include "application.hpp"
+#include "simple_logger.hpp"
 
-#include <MCLogger>
 #include <exception>
 
 namespace {
@@ -23,7 +23,7 @@ static const char * INIT_ERROR = "Initializing the game failed!";
 }
 
 Application::Application(int & argc, char ** argv)
-    : QApplication(argc, argv)
+  : QApplication(argc, argv)
 {
 }
 
@@ -32,11 +32,10 @@ bool Application::notify(QObject * receiver, QEvent * event)
     try
     {
         return QApplication::notify(receiver, event);
-    }
-    catch (std::exception & e)
+    } catch (std::exception & e)
     {
-        MCLogger().fatal() << e.what();
-        MCLogger().fatal() << INIT_ERROR;
+        juzzlin::L().fatal() << e.what();
+        juzzlin::L().fatal() << INIT_ERROR;
 
         QApplication::exit(EXIT_FAILURE);
 
