@@ -18,6 +18,8 @@
 
 #include "renderable.hpp"
 
+#include <memory>
+
 class MCSurface;
 class Car;
 
@@ -25,7 +27,6 @@ class Car;
 class CarStatusView : public Renderable
 {
 public:
-
     //! Constructor.
     CarStatusView();
 
@@ -35,9 +36,10 @@ public:
     void setCarToFollow(const Car & car);
 
 private:
+    std::shared_ptr<MCSurface> m_body;
+
+    std::shared_ptr<MCSurface> m_tires;
 
-    MCSurface & m_body;
-    MCSurface & m_tires;
     const Car * m_car;
 };
 
