@@ -20,18 +20,18 @@
 #include <MCSurface>
 #include <MCVector3d>
 
-static const int   FLAG_W           = 32;
-static const int   FLAG_H           = 24;
-static const int   V_SPACING        = 20;
+static const int FLAG_W = 32;
+static const int FLAG_H = 24;
+static const int V_SPACING = 20;
 
 CheckeredFlag::CheckeredFlag()
-: m_surface(MCAssetManager::surfaceManager().surface("checkeredFlag"))
+  : m_surface(MCAssetManager::surfaceManager().surface("checkeredFlag"))
 {
 }
 
 void CheckeredFlag::render()
 {
     MCVector3dF pos(width() / 2, height() - FLAG_H / 2 - V_SPACING);
-    m_surface.setSize(FLAG_W, FLAG_H);
-    m_surface.render(nullptr, pos, 0);
+    m_surface->setSize(FLAG_W, FLAG_H);
+    m_surface->render(nullptr, pos, 0);
 }
