@@ -27,6 +27,7 @@
 #include "settings.hpp"
 
 class AudioWorker;
+class Database;
 class EventHandler;
 class InputHandler;
 class Renderer;
@@ -147,6 +148,8 @@ private:
 
     QTranslator m_appTranslator;
 
+    std::unique_ptr<Database> m_database;
+
     bool m_forceNoVSync;
 
     Settings m_settings;
