@@ -8,14 +8,14 @@ const unsigned int LSHIFT = 50;
 
 const unsigned int RSHIFT = 62;
 
-const unsigned int LCTRL  = 37;
+const unsigned int LCTRL = 37;
 
-const unsigned int RCTRL  = 105;
+const unsigned int RCTRL = 105;
 
-const unsigned int LALT   = 64;
+const unsigned int LALT = 64;
 
-const unsigned int RALT   = 92;
+const unsigned int RALT = 92;
 
-}
+} // namespace KeyCodes
 
 #endif // KEYCODES_HPP
