@@ -28,7 +28,6 @@
 #include "simple_logger.hpp"
 
 #include <iostream>
-#include <memory>
 #include <string>
 #include <vector>
 
@@ -38,7 +37,7 @@ static void initLogger()
 {
     QString logPath = QDir::tempPath() + QDir::separator() + "dr2d.log";
     L::init(logPath.toStdString().c_str());
-    L::enableDateTime(true);
+    L::setTimestampMode(L::TimestampMode::DateTime);
     L::setLevelSymbol(L::Level::Trace, "<T>");
     L::setLevelSymbol(L::Level::Debug, "<D>");
     L::setLevelSymbol(L::Level::Info, "<I>");
@@ -51,35 +50,24 @@ static void initLogger()
 
 int main(int argc, char ** argv)
 {
-    QApplication::setOrganizationName(Config::General::QSETTINGS_COMPANY_NAME);
-    QApplication::setApplicationName(Config::Game::QSETTINGS_SOFTWARE_NAME);
+    QApplication::setOrganizationName(Config::General::QT_ORGANIZATION_NAME);
+    QApplication::setApplicationName(Config::Game::QT_APPLICATION_NAME);
 #ifdef Q_OS_WIN32
     QSettings::setDefaultFormat(QSettings::IniFormat);
 #endif
 
-    std::unique_ptr<Game> game;
-
     try
     {
         initLogger();
-
-        // Create the main game object. The game loop starts immediately after
-        // the Renderer has been initialized.
-        L().debug() << "Creating game object..";
-
-        game = std::make_unique<Game>(argc, argv);
-
-        return game->run();
-    } catch (std::exception & e)
+        return Game(argc, argv).run();
+    } //
+    catch (std::exception & e)
     {
         if (!dynamic_cast<UserException *>(&e))
         {
             L().fatal() << e.what();
             L().fatal() << "Initializing the game failed!";
         }
-
-        game.reset();
-
         return EXIT_FAILURE;
     }
 }
