@@ -24,9 +24,8 @@ class TrackData;
 class Map : public MapBase
 {
 public:
-
     //! Constuctor.
-    Map(unsigned int cols, unsigned int rows);
+    Map(size_t cols, size_t rows);
 
     //! Destructor.
     virtual ~Map();
