@@ -25,7 +25,6 @@ class MCTextureFont;
 class Credits : public SurfaceMenu
 {
 public:
-
     //! Constructor.
     Credits(std::string id, int width, int height);
 
@@ -33,12 +32,11 @@ public:
     virtual void render() override;
 
 private:
-
     std::vector<MCTextureText> m_texts;
 
     int m_time = 0;
 
-    int m_textIndex = 0;
+    size_t m_textIndex = 0;
 };
 
 #endif // CREDITS_HPP
