@@ -16,6 +16,8 @@
 #ifndef OFFTRACKDETECTOR_HPP
 #define OFFTRACKDETECTOR_HPP
 
+#include <memory>
+
 #include <MCVector2d>
 
 class Car;
@@ -26,24 +28,22 @@ class TrackTile;
 class OffTrackDetector
 {
 public:
-
     //! Constructor.
     OffTrackDetector(Car & car);
 
     //! Set the current track.
-    void setTrack(Track & track);
+    void setTrack(std::shared_ptr<Track> track);
 
     //! Update.
     void update();
 
 private:
-
     //! Test if the given location is off the track on the given tile.
     bool isOffTrack(MCVector2dF tire, const TrackTile & tile) const;
 
     Car & m_car;
 
-    Track * m_track;
+    std::shared_ptr<Track> m_track;
 
     float m_tileWLimit;
 
